/*
 * gen_image.c - Part of psiconv, a PSION 5 file formats converter
 * Copyright (c) 1999  Frodo Looijaard <frodol@dds.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "config.h"
#include "data.h"
#include "gen.h"
#include <string.h>
#include "psiconv.h"

#if IMAGEMAGICK
#include <magick/magick.h>
#endif

/* This is ridiculously simple using ImageMagick. Without it, it would
   be quite somewhat harder - it will be left for later on */

static void gen_paint_data_section(FILE *of, psiconv_paint_data_section sec,
                                   const char *dest)
{
#if IMAGEMAGICK
  ImageInfo image_info;
  Image *image;
 
  image = CreateImage(sec->xsize,sec->ysize,sec->red,sec->green,
                             sec->blue,NULL);
  GetImageInfo(&image_info);
  image_info.file = of; 
  strcpy(image->magick, dest);
  WriteImage(&image_info,image);
#endif
}

static void psiconv_gen_image_mbm(FILE *of, psiconv_mbm_f f, const char *dest)
{
  psiconv_paint_data_section section;
  if (psiconv_list_length(f->sections) >= 1) {
    section = psiconv_list_get(f->sections,0);
    gen_paint_data_section(of,section,dest);
  }
}

static void psiconv_gen_image_sketch(FILE *of, psiconv_sketch_f f, 
                                     const char * dest)
{
  gen_paint_data_section(of,f->sketch_sec->picture,dest);
}

static int psiconv_gen_image(FILE * of, const psiconv_file file, 
                             const char *dest)
{
  if (file->type == psiconv_mbm_file) {
    psiconv_gen_image_mbm(of,(psiconv_mbm_f) file->file,dest);
    return 0;
  } else if (file->type == psiconv_sketch_file) {
    psiconv_gen_image_sketch(of,(psiconv_sketch_f) file->file,dest);
    return 0;
  } else
    return -1;
}

void init_image(void)
{
  struct psiconv_fileformat ff;
#if IMAGEMAGICK
  MagickInfo *mi;
  ff.output = psiconv_gen_image;
  for (mi = GetMagickInfo(NULL); mi ; mi = mi->next) {
    if (mi->encoder) {
      ff.name = strdup(mi->tag);
      ff.description = strdup(mi->description);
      psiconv_list_add(fileformat_list,&ff);
    }
  }
#endif
}

